==> open-xchange-guard_2.4.0.orig.tar.bz2: open-xchange-guard-2.4.0/com.openexchange.guard.session/src/com/openexchange/guard/session/internal/GuardSessionStorage.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.session.internal;

import com.openexchange.exception.OXException;

/**
 * {@link GuardSessionStorage} provides access to stored OX Guard session information
 */
public interface GuardSessionStorage {

    /**
     * Creates or updates a new session
     * 
     * @param sessionId the session to create
     * @param token the authentication token
     * @param userId the userId
     * @param contextId the contextId
     */
    public void InsertOrUpdate(String sessionId, String token, int userId, int contextId) throws OXException;

    /**
     * Get's a session by id
     * 
     * @param sessionId the session id
     * @return the session for the given sessionId or null if no such session was found or an error occurred
     */
    public GuardSession getById(String sessionId) throws OXException;

    /**
     * Deletes a session
     * 
     * @param sessionId the id of the session to delete
     */
    public void deleteById(String sessionId) throws OXException;

    /**
     * Deletes sessions which are older than x days
     * 
     * @param days the days
     */
    public void deleteOldSessions(int days) throws OXException;
}

==> open-xchange-guard_2.10.1.orig.tar.bz2: open-xchange-guard-2.10.1/com.openexchange.guard.session/src/com/openexchange/guard/session/internal/GuardSessionStorage.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.session.internal;

import com.openexchange.exception.OXException;

/**
 * {@link GuardSessionStorage} provides access to stored OX Guard session information
 */
public interface GuardSessionStorage {

    /**
     * Creates or updates a new session
     * 
     * @param sessionId the session to create
     * @param token the authentication token
     * @param userId the userId
     * @param contextId the contextId
     */
    public void InsertOrUpdate(String sessionId, String token, int userId, int contextId) throws OXException;

    /**
     * Get's a session by id
     * 
     * @param sessionId the session id
     * @return the session for the given sessionId or null if no such session was found or an error occurred
     */
    public GuardSession getById(String sessionId) throws OXException;

    /**
     * Deletes a session
     * 
     * @param sessionId the id of the session to delete
     */
    public void deleteById(String sessionId) throws OXException;

    /**
     * Deletes sessions which are older than the given amount of milliseconds
     * 
     * @param milliSeconds the milliseconds
     * @return The amount of session which have been removed 
     */
    public int deleteOldSessions(long milliSeconds) throws OXException;
}
